/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author Peter Yoo
 */
public class MultiPattern {

	public MultiPattern(String... patternStrings) {
		_patterns = new ArrayList<>(patternStrings.length);

		for (String patternString : patternStrings) {
			_patterns.add(Pattern.compile(patternString));
		}
	}

	public Matcher find(String input) {
		for (Pattern pattern : _patterns) {
			Matcher matcher = pattern.matcher(input);

			if (matcher.find()) {
				return matcher;
			}
		}

		return null;
	}

	public int getSize() {
		return _patterns.size();
	}

	public int indexOf(Pattern pattern) {
		return _patterns.indexOf(pattern);
	}

	public Matcher matches(String input) {
		for (Pattern pattern : _patterns) {
			Matcher matcher = pattern.matcher(input);

			if (matcher.matches()) {
				return matcher;
			}
		}

		return null;
	}

	private final List<Pattern> _patterns;

}