/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import java.io.IOException;

/**
 * @author Michael Hashimoto
 * @author Peter Yoo
 */
public class SubrepositoryGitWorkingDirectory extends GitWorkingDirectory {

	protected SubrepositoryGitWorkingDirectory(
			String upstreamBranchName, String workingDirectoryPath)
		throws IOException {

		super(upstreamBranchName, workingDirectoryPath);
	}

	protected SubrepositoryGitWorkingDirectory(
			String upstreamBranchName, String workingDirectoryPath,
			String repositoryName)
		throws IOException {

		super(upstreamBranchName, workingDirectoryPath, repositoryName);
	}

	@Override
	protected void setUpstreamRemoteToPrivateRepository() {
		Remote upstreamRemote = getUpstreamRemote();

		String remoteURL = upstreamRemote.getRemoteURL();

		if (!remoteURL.contains("-private")) {
			remoteURL = remoteURL.replace(".git", "-private.git");
		}

		addRemote(true, "upstream-temp", remoteURL);
	}

	@Override
	protected void setUpstreamRemoteToPublicRepository() {
		Remote upstreamRemote = getUpstreamRemote();

		String remoteURL = upstreamRemote.getRemoteURL();

		if (remoteURL.contains("-private")) {
			remoteURL = remoteURL.replace("-private", "");
		}

		addRemote(true, "upstream-temp", remoteURL);
	}

}